/*
 * Demo des Watchdogs (MSPG2553 & Grace)		17.3.2012 G.Li
 * Mit Timer0 wird er zurckgesetzt
 * Timer0 1 Sekunde der Watchdog schlgt zu, da nur eine Wartezeit von 250ms hat,
 * als Folge wird main neu gestartet (PUC) und LED blitzt periodisch auf.
 * Timer0 100 ms, kein Restart, kein Blitzen
 *
 * Grundlagen:
 * WDTCTL = WDTPW + WDTCNTCL;	// wrde Fehler ergeben, siehe hier Kommentar im Netz:
 * http://www.mikrocontroller.net/topic/103634#2435141
 * #define WDT_ARST_250        (WDTPW+WDTCNTCL+WDTSSEL+WDTIS0)                   "250ms"
 * aus MSP430G2553.h
 *
 * ======== Standard MSP430 includes ========
 */
#include <msp430.h>
extern void NMIISRHandler(void);
extern void OFIEHandler(void);
extern void T0_ISR(void);

/*
 * ======== Grace related includes ========
 */
#include <ti/mcu/msp430/csl/CSL.h>

/*
 *  ======== main ========
 */
int main(int argc, char *argv[])
{
    CSL_init();                     // Activate Grace-generated configuration
    
    // >>>>> Fill-in user code here <<<<<
	P1OUT |= 0x01 ;      		// um Restart nach Watchdog sichtbar zu machen
    __delay_cycles(50000);      // um Restart sichtbar zu machen
	P1OUT &= ~0x01 ;      		// um Restart sichtbar zu machen

	WDTCTL = WDTPW + WDTSSEL + WDTIS0 + WDTCNTCL;   // Watchdog einschalten

	_BIS_SR(LPM0_bits + GIE);                 // Enter LPM3 w/interrupt

    return (0);
}


void NMIISRHandler(void)
{
    // XT1/XT2 Failure Detected
    do {
        IFG1 &= ~OFIFG;             // Clear OSC Fault flag
        __delay_cycles(50000);      // Time for flag to set again
    } while (IFG1 & OFIFG);         // Loop while OSC Fault flag is set
    IE1 |= OFIE;                    // re-enable osc fault interrupt
}

void OFIEHandler(void)
{
	P1OUT |= 0x01 ;				// wird in der Regel nicht aktiviert
}

void T0_ISR(void)
{
	WDTCTL = WDT_ARST_250 ;		// besser, WDT is clocked by fACLK (32KHz), 250ms
}


